////////////////////////////////////////////////////////////////////// 
// lamp/ModelSummary.h 
// (c) 2000-2006 Goncalo Abecasis
// 
// This file is distributed as part of the LAMP source code package   
// and may not be redistributed in any form, without prior written    
// permission from the author. Permission is granted for you to       
// modify this file for your own personal use, but modified versions  
// must retain this copyright notice and must not be distributed.     
// 
// Permission is granted for you to use this file to compile LAMP.    
// 
// All computer programs have bugs. Use this file at your own risk.   
// 
// Friday September 01, 2006
// 
 
#ifndef __MODELSUMMARY_H__
#define __MODELSUMMARY_H__

#include "MathVector.h"

#include <stdio.h>

#define __LAMP_LINKAGE_MODEL__      0
#define __LAMP_ASSOC_MODEL__        1
#define __LAMP_CAUSAL_MODEL__       2

class ModelSummary
    {
    public:
        static bool skipDetails; 

        ModelSummary();

        void OpenFile(const char * filename);
        void CloseFile();

        void OutputModel(int model);
        void OutputHeader(int model);

        void BaseModelHeader();
        void LinkageHeader();
        void IndirectAssociationHeader();
        void DirectAssociationHeader();

        void OutputBaseModel();
        void OutputLinkageModel();
        void OutputIndirectAssociationModel();
        void OutputDirectAssociationModel();

        int    markerId;
        String marker;
        String trait;

        double loglikelihood;
        int    fittedParameters;

        Vector frequencies;
        double penetrances[3];

        double lambdaS(double daf);
        double lambdaMarker();
        double attributableFraction(double daf);

    protected:
        void GenericHeader(const char * modelType, const char * blurb);
        void BeginSection(const char * modelType);
        void EndSection();
        void OutputDiseaseModel();

    private:
        FILE * output;
        String openfile;

        bool   hasOutput;

        void   Swap(double & a, double & b) {double tmp = a; a = b; b = tmp; }
        double Square(double a)             {return a * a; }
    };

#endif


 
